[hide private]
[frames] | no frames]

[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - exceptions.BaseException: Common base class for all exceptions
    - pysmime.util.BadKeyringSource: Exception raised if selected Keyring source is not valid.
    - pysmime.core.BadPKCS7Type: Exception raised if requested PKCS#7 type is not valid.
    - pysmime.core.CertStoreNotAvailable: Exception raised if the reference certstore for verification is not available.
    - pysmime.core.MissingSignerCertificate: Exception raised if the input PKCS#7 is not a signed PKCS#7.